@@ -1306,7 +1306,7 @@ display_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 
 #ifdef HAVE_RSVG
 	if (eom_image_is_svg (view->priv->image)) {
-		cairo_matrix_t matrix, translate, scale;
+		cairo_matrix_t matrix, translate, scale, original;
 		EomTransform *transform = eom_image_get_transform (priv->image);
 		cairo_matrix_init_identity (&matrix);
 		if (transform) {
@@ -1343,6 +1343,8 @@ display_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 		cairo_matrix_init_translate (&translate, xofs, yofs);
 		cairo_matrix_multiply (&matrix, &matrix, &translate);
 
+		cairo_get_matrix (cr, &original);
+		cairo_matrix_multiply (&matrix, &matrix, &original);
 		cairo_set_matrix (cr, &matrix);
 
 		rsvg_handle_render_cairo (eom_image_get_svg (priv->image), cr);
@@ -1353,9 +1355,10 @@ display_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 		cairo_scale (cr, priv->zoom, priv->zoom);
 		cairo_set_source_surface (cr, priv->surface, xofs/priv->zoom, yofs/priv->zoom);
 		cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_PAD);
-		if ((is_zoomed_in (view) && priv->interp_type_in == CAIRO_FILTER_NEAREST) ||
-		    (is_zoomed_out (view) && priv->interp_type_out == CAIRO_FILTER_NEAREST))
-			cairo_pattern_set_filter (cairo_get_source (cr), CAIRO_FILTER_NEAREST);
+		if (is_zoomed_in (view))
+			cairo_pattern_set_filter (cairo_get_source (cr), priv->interp_type_in);
+		else if (is_zoomed_out (view))
+			cairo_pattern_set_filter (cairo_get_source (cr), priv->interp_type_out);
 		cairo_paint (cr);
 	}
 
